@@ -579,6 +579,7 @@ class Plan(HeadersMixin):
                             timeouts=test.get("timeouts"),
                             callback=test.get("callback"),
                             wait_for=build.uid,
+                            command=test.get("commands", []),
                         )
                     )
                 self.builds.append(build)
@@ -608,6 +609,7 @@ class Plan(HeadersMixin):
                             tests=test.get("tests", []),
                             timeouts=test.get("timeouts"),
                             callback=test.get("callback"),
+                            command=test.get("commands", []),
                         )
                     )
 
@@ -897,6 +899,7 @@ class Test(HeadersMixin):
     tests = attrib(default=[])
     timeouts = attrib(default=[])
     callback = attrib(default=None)
+    command = attrib(default=[])
 
     uid = attrib(default=None)
     wait_for = attrib(default=None)
@@ -937,6 +940,8 @@ class Test(HeadersMixin):
             data["waiting_for"] = self.wait_for
         if self.callback:
             data["callback"] = self.callback
+        if self.command:
+            data["command"] = self.command
         if plan is not None:
             data["plan"] = plan
 
