@@ -7,3 +7,5 @@ PASS = "🎉"
 WARNING = "👾"
 FAIL = "👹"
 ERROR = "🔧"
+CANCELED = "⚠️ "
+UNKNOWN = "🧐"
