@@ -315,6 +315,7 @@ def handle_submit(cmdargs, _, config):
             timeouts=timeouts_d,
             wait_for=cmdargs.wait_for,
             callback=cmdargs.callback,
+            command=cmdargs.commands,
         )
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
         error(e)
@@ -471,6 +472,12 @@ def test_cmd_options(sp):
         ),
         type=is_url,
     )
+    sp.add_argument(
+        "--commands",
+        nargs="*",
+        help="Space separated list of commands to run inside the VM",
+        default=[],
+    )
 
 
 def setup_parser(parser):
